diff --git a/CHANGELOG.md b/CHANGELOG.md
index 6f4b9ac3e..e4e90bda0 100644
--- a/CHANGELOG.md
+++ b/CHANGELOG.md
@@ -1,3 +1,7 @@
+# v5.0.0-alpha3
+
+- Add fix to the update script, so that upgrading JCB from Joomla 4 to 5 will not fail.
+
# v5.0.0-alpha2
- Fix the plug-in installer script builder bug #1067
@@ -7,9 +11,9 @@
- First alpha release of Component Builder towards Joomla 5 (very unstable...)
-# v4.0.0-alpha2
+# v4.0.0-alpha3
-- Fix the plug-in installer script builder bug #1067
+- Add fix to the update script, so that upgrading JCB from Joomla 3 to 4 will not fail.
# v3.2.0-beta6
diff --git a/README.md b/README.md
index 55ee18981..7367e4efd 100644
--- a/README.md
+++ b/README.md
@@ -9,7 +9,7 @@ The Component Builder for [Joomla](https://extensions.joomla.org/extension/compo
Whether you're a seasoned [Joomla](https://extensions.joomla.org/extension/component-builder/) developer, or have just started, Component Builder will save you lots of time and money. A real must have!
-You can install it quite easily and with no limitations. On [gitea](https://git.vdm.dev/joomla/Component-Builder/tags) is the latest release (5.0.0-alpha2) with **ALL** its features and **ALL** concepts totally open-source and free!
+You can install it quite easily and with no limitations. On [gitea](https://git.vdm.dev/joomla/Component-Builder/tags) is the latest release (5.0.0-alpha3) with **ALL** its features and **ALL** concepts totally open-source and free!
> Watch Quick Build of a Hello World component in [JCB on Youtube](https://www.youtube.com/watch?v=IQfsLYIeblk&list=PLQRGFI8XZ_wtGvPQZWBfDzzlERLQgpMRE&index=45)
@@ -144,13 +144,13 @@ TODO
+ *Author*: [Llewellyn van der Merwe](mailto:joomla@vdm.io)
+ *Name*: [Component Builder](https://git.vdm.dev/joomla/Component-Builder)
+ *First Build*: 30th April, 2015
-+ *Last Build*: 11th March, 2024
-+ *Version*: 5.0.0-alpha2
++ *Last Build*: 12th March, 2024
++ *Version*: 5.0.0-alpha3
+ *Copyright*: Copyright (C) 2015 Vast Development Method. All rights reserved.
+ *License*: GNU General Public License version 2 or later; see LICENSE.txt
-+ *Line count*: **725286**
++ *Line count*: **725315**
+ *Field count*: **2078**
-+ *File count*: **5117**
++ *File count*: **5118**
+ *Folder count*: **518**
> This **component** was build with a [Joomla](https://extensions.joomla.org/extension/component-builder/) [Automated Component Builder](https://www.joomlacomponentbuilder.com).
diff --git a/admin/README.txt b/admin/README.txt
index 55ee18981..7367e4efd 100644
--- a/admin/README.txt
+++ b/admin/README.txt
@@ -9,7 +9,7 @@ The Component Builder for [Joomla](https://extensions.joomla.org/extension/compo
Whether you're a seasoned [Joomla](https://extensions.joomla.org/extension/component-builder/) developer, or have just started, Component Builder will save you lots of time and money. A real must have!
-You can install it quite easily and with no limitations. On [gitea](https://git.vdm.dev/joomla/Component-Builder/tags) is the latest release (5.0.0-alpha2) with **ALL** its features and **ALL** concepts totally open-source and free!
+You can install it quite easily and with no limitations. On [gitea](https://git.vdm.dev/joomla/Component-Builder/tags) is the latest release (5.0.0-alpha3) with **ALL** its features and **ALL** concepts totally open-source and free!
> Watch Quick Build of a Hello World component in [JCB on Youtube](https://www.youtube.com/watch?v=IQfsLYIeblk&list=PLQRGFI8XZ_wtGvPQZWBfDzzlERLQgpMRE&index=45)
@@ -144,13 +144,13 @@ TODO
+ *Author*: [Llewellyn van der Merwe](mailto:joomla@vdm.io)
+ *Name*: [Component Builder](https://git.vdm.dev/joomla/Component-Builder)
+ *First Build*: 30th April, 2015
-+ *Last Build*: 11th March, 2024
-+ *Version*: 5.0.0-alpha2
++ *Last Build*: 12th March, 2024
++ *Version*: 5.0.0-alpha3
+ *Copyright*: Copyright (C) 2015 Vast Development Method. All rights reserved.
+ *License*: GNU General Public License version 2 or later; see LICENSE.txt
-+ *Line count*: **725286**
++ *Line count*: **725315**
+ *Field count*: **2078**
-+ *File count*: **5117**
++ *File count*: **5118**
+ *Folder count*: **518**
> This **component** was build with a [Joomla](https://extensions.joomla.org/extension/component-builder/) [Automated Component Builder](https://www.joomlacomponentbuilder.com).
diff --git a/admin/sql/updates/mysql/4.0.0-alpha2.sql b/admin/sql/updates/mysql/4.0.0-alpha3.sql
similarity index 100%
rename from admin/sql/updates/mysql/4.0.0-alpha2.sql
rename to admin/sql/updates/mysql/4.0.0-alpha3.sql
diff --git a/admin/sql/updates/mysql/5.0.0-alpha2.sql b/admin/sql/updates/mysql/5.0.0-alpha2.sql
new file mode 100644
index 000000000..8b1378917
--- /dev/null
+++ b/admin/sql/updates/mysql/5.0.0-alpha2.sql
@@ -0,0 +1 @@
+
diff --git a/componentbuilder.xml b/componentbuilder.xml
index 9f038225b..c0661623f 100644
--- a/componentbuilder.xml
+++ b/componentbuilder.xml
@@ -1,15 +1,15 @@
COM_COMPONENTBUILDER
- 11th March, 2024
+ 12th March, 2024
Llewellyn van der Merwe
joomla@vdm.io
https://dev.vdm.io
Copyright (C) 2015 Vast Development Method. All rights reserved.
GNU General Public License version 2 or later; see LICENSE.txt
- 5.0.0-alpha2
+ 5.0.0-alpha3
Component Builder (v.5.0.0-alpha2)
+ Component Builder (v.5.0.0-alpha3)
The Component Builder for [Joomla](https://extensions.joomla.org/extension/component-builder/) is highly advanced tool that is truly able to build extremely complex components in a fraction of the time.
diff --git a/componentbuilder_update_server.xml b/componentbuilder_update_server.xml
index b102315ca..b9a2003d5 100644
--- a/componentbuilder_update_server.xml
+++ b/componentbuilder_update_server.xml
@@ -23,13 +23,13 @@
pkg_component_builder
package
site
- 4.0.0-alpha2
+ 4.0.0-alpha3
https://dev.vdm.io
- https://git.vdm.dev/api/v1/repos/joomla/pkg-component-builder/archive/v4.0.0-alpha2.zip
+ https://git.vdm.dev/api/v1/repos/joomla/pkg-component-builder/archive/v4.0.0-alpha3.zip
- stable
+ alpha
Llewellyn van der Merwe
https://dev.vdm.io
@@ -47,7 +47,7 @@
https://git.vdm.dev/api/v1/repos/joomla/pkg-component-builder/archive/v5.0.0-alpha1.zip
- beta
+ alpha
Llewellyn van der Merwe
https://dev.vdm.io
@@ -62,13 +62,31 @@
5.0.0-alpha2
https://dev.vdm.io
- https://git.vdm.dev/api/v1/repos/joomla/pkg-component-builder/archive/v5.0.0-alpha1.zip
+ https://git.vdm.dev/api/v1/repos/joomla/pkg-component-builder/archive/v5.0.0-alpha2.zip
- beta
+ alpha
Llewellyn van der Merwe
https://dev.vdm.io
-
+
+
+
+ Component Builder
+ Builds Complex Joomla Components
+ pkg_component_builder
+ package
+ site
+ 5.0.0-alpha3
+ https://dev.vdm.io
+
+ https://git.vdm.dev/api/v1/repos/joomla/pkg-component-builder/archive/v5.0.0-alpha3.zip
+
+
+ alpha
+
+ Llewellyn van der Merwe
+ https://dev.vdm.io
+
\ No newline at end of file
diff --git a/ComponentbuilderInstallerScript.php b/ComponentbuilderInstallerScript.php
index 42c3a5eeb..844f9e626 100644
--- a/ComponentbuilderInstallerScript.php
+++ b/ComponentbuilderInstallerScript.php
@@ -545,10 +545,16 @@ class Com_ComponentbuilderInstallerScript implements InstallerScriptInterface
// do any updates needed
if ($type === 'update')
{
- // path to the new compiler
- $jcb_powers = JPATH_LIBRARIES . '/jcb_powers/VDM.Joomla/src/Componentbuilder';
- // we always remove all the old files to avoid mismatching
- \VDM\Component\Componentbuilder\Administrator\Helper\ComponentbuilderHelper::removeFolder($jcb_powers);
+
+ // Check if the class and method exist before attempting to call it.
+ if (class_exists('\VDM\Component\Componentbuilder\Administrator\Helper\ComponentbuilderHelper') &&
+ method_exists('\VDM\Component\Componentbuilder\Administrator\Helper\ComponentbuilderHelper', 'removeFolder'))
+ {
+ // path to the new compiler
+ $jcb_powers = JPATH_LIBRARIES . '/jcb_powers/VDM.Joomla/src/Componentbuilder';
+ // we always remove all the old files to avoid mismatching
+ \VDM\Component\Componentbuilder\Administrator\Helper\ComponentbuilderHelper::removeFolder($jcb_powers);
+ }
}
// do any install needed
@@ -3140,7 +3146,7 @@ class Com_ComponentbuilderInstallerScript implements InstallerScriptInterface
echo '
-
Upgrade to Version 5.0.0-alpha2 Was Successful! Let us know if anything is not working as expected.
';
+ Upgrade to Version 5.0.0-alpha3 Was Successful! Let us know if anything is not working as expected.
';
// Add/Update component in the action logs extensions table.
$this->setActionLogsExtensions();